//=============================================================================
// Project:    SLP - An Interpreter for Super Logic Programs / Static Semantics
// Module:     in_cgi.h
// Purpose:    Get Input Via Common Gateway Interface (CGI) - Method POST
// Last Change:29.03.2001
// Language:   C++
// Author:     Stefan Brass
// Email:      Stefan.Brass@informatik.uni-giessen.de, sbrass@sis.pitt.edu
// Address:    Universitaet Giessen, Arndtstr. 2, 35392 Giessen, Germany
// Copyright:  (c) 1998-2001 by Stefan Brass
// Licence:    Distributed under the conditions of the GNU Public Licence.
//=============================================================================

//=============================================================================
// Include File Frame:
//=============================================================================

#ifndef	IN_CGI_INCLUDED
#define IN_CGI_INCLUDED

//=============================================================================
// Used Types and Macros:
//=============================================================================

#ifndef BOOL_INCLUDED
#include "bool.h"
#endif

#ifndef STR_INCLUDED
#include "str.h"
#endif

#ifndef CHECK_INCLUDED
#include "check.h"
#endif

#ifndef IN_INCLUDED
#include "in.h"
#endif

//=============================================================================
// Class for Input File:
//=============================================================================

class in_cgi_c : public in_c {

	public:

//-----------------------------------------------------------------------------
// Constructor:
//-----------------------------------------------------------------------------

	in_cgi_c(void);

//-----------------------------------------------------------------------------
// Destructor:
//-----------------------------------------------------------------------------

	~in_cgi_c(void);

//-----------------------------------------------------------------------------
// close: Close input explicitly.
//-----------------------------------------------------------------------------

	bool_t	close(void);

//-----------------------------------------------------------------------------
// read: Read characters from input file into buffer.
//-----------------------------------------------------------------------------

	int	read(char *buf, int size);

//-----------------------------------------------------------------------------
// is_open: Is this input stream currently open?
//-----------------------------------------------------------------------------

	inline bool_t	is_open(void)
		{ return(BufPtr != 0); }

//-----------------------------------------------------------------------------
// filename: Name of this "file" (None).
//-----------------------------------------------------------------------------

	inline str_t	filename(void)
		{ return(STR_NIL); }

//=============================================================================
// Private Class Members:
//=============================================================================

	private:

//-----------------------------------------------------------------------------
// Buf: Input buffer.
//-----------------------------------------------------------------------------

	char*	Buf;

//-----------------------------------------------------------------------------
// BufSize: Size of input buffer.
//-----------------------------------------------------------------------------

	int	BufSize;

//-----------------------------------------------------------------------------
// BufPtr: Pointer to character in buffer which will be returned on next read.
//-----------------------------------------------------------------------------

	char*	BufPtr;

//=============================================================================
// Auxillary Functions:
//=============================================================================

	private:

//-----------------------------------------------------------------------------
// input_size: Check the relevant environment variables, return input size.
//-----------------------------------------------------------------------------

	int input_size(void);

//-----------------------------------------------------------------------------
// decode: Decode a HTTP-string.
//-----------------------------------------------------------------------------

	bool_t decode(char* buf);

//-----------------------------------------------------------------------------
// hex: Return value of hexadecimal digit (-1000 if not valid).
//-----------------------------------------------------------------------------

	int hex(char c);

//=============================================================================
// End of Class:
//=============================================================================

};

//-----------------------------------------------------------------------------
// Define pointer type:
//-----------------------------------------------------------------------------

typedef in_cgi_c *in_cgi_t;

//=============================================================================
// End of File:
//=============================================================================

#endif

